@@ -375,7 +375,9 @@ class Utils:
               help='Target repository (default is current directory)')
 @click.option('-r', '--merge-request', is_flag=True, default=False,
               help='Create merge request. Requires --push. (default is False)')
-def cli(issue_id_or_url, name_only, push, target: Path, merge_request):
+@click.option('-s', '--source-branch', default='develop',
+              help='Source branch')
+def cli(issue_id_or_url, name_only, push, target: Path, merge_request: bool, source_branch: str):
     """Simple program that takes a JIRA issue ID and creates a new local and tracking remote branch"""
 
     issue_id = issue_id_or_url
@@ -409,7 +411,7 @@ def cli(issue_id_or_url, name_only, push, target: Path, merge_request):
     else:
         target_branch = None
         try:
-            target_branch = create_branch(branch_name, push, target)
+            target_branch = create_branch(branch_name, push, target, source_branch)
         except Exception:
             exit(1)
         if target_branch and merge_request:
